Branch Creation
---------------

Issues are resolved using pull requests.
The branch name will be of the form :code:`issue-[0-9]*` where :code:`[0-9]*` is the issue number.

This will make it easy to link the issue in GitHub with the code that addresses the issue.
